package com.github.braillesystems.learnbraille.res

import com.github.braillesystems.learnbraille.data.dsl.annotate
import com.github.braillesystems.learnbraille.data.dsl.lessons
import com.github.braillesystems.learnbraille.data.entities.*
import com.github.braillesystems.learnbraille.data.entities.BrailleDot.E
import com.github.braillesystems.learnbraille.data.entities.BrailleDot.F

internal val golubinaIntroLessons by lessons {

    val name1 = "Знакомство с шеститочием"
    lesson(
        name = name1
    ) {
        +FirstInfo(
            """Перед Вами пошаговый курс для обучения с нуля системе Луи Брайля.
                <br><br>
                Курс построен на основе книги В. В. Голубиной "Пособие по изучению системы Л. Брайля".
                В течение курса Вы ознакомитесь с обозначениями букв, цифр и специальных символов.
                В некоторых шагах предлагается выполнять задания, используя книгу Голубиной.
                Если Вам будет непонятно, как пользоваться курсом, Вы в любой момент можете вызвать справку
                по разделу, нажав кнопку "справка" в правом верхнем углу экрана.
            """
        )
        +Info(
            """
                <b>Урок 1. Тренировка чтения и ввода отдельных комбинаций.</b>
                <br><br>
                В азбуке Брайля любой символ - это шеститочие.
                <br>
                Точки расположены в два столбца по три.
                <br> 
                Точки в первом столбце имеют номера 1, 2, 3 сверху вниз. 
                Во втором столбце - 4, 5, 6 сверху вниз.
                """
        )
        +ShowDots(
            text = "Перед Вами символ Брайля - <br>" +
                    " точка номер один",
            dots = BrailleDots(F, E, E, E, E, E)
        )
        +InputDots(
            text = "Введите точку один",
            dots = BrailleDots(F, E, E, E, E, E)
        )
        +ShowDots(
            text = "Точка номер два",
            dots = BrailleDots(E, F, E, E, E, E)
        )
        +InputDots(
            text = "Введите точку два",
            dots = BrailleDots(E, F, E, E, E, E)
        )
        +ShowDots(
            text = "Комбинация точек 1 и 2",
            dots = BrailleDots(F, F, E, E, E, E)
        )
        +InputDots(
            text = "Введите комбинацию: точки 1 и 2",
            dots = BrailleDots(F, F, E, E, E, E)
        )
        +InputDots(
            text = "Введите комбинацию точек 1 и 3",
            dots = BrailleDots(F, E, F, E, E, E)
        )
        +InputDots(
            text = "Введите комбинацию точек 1, 3 и 4",
            dots = BrailleDots(F, E, F, F, E, E)
        )
        +InputDots(
            // repeat = 3
            text = "Введите комбинацию точек 1, 3 и 6",
            dots = BrailleDots(F, E, F, E, E, F)
        )
        +InputDots(
            // repeat = 3
            text = "Введите комбинацию точек 1, 5 и 6",
            dots = BrailleDots(F, E, E, E, F, F)
        )
        +InputDots(
            // repeat = 3
            text = "Введите комбинацию точек 2, 3, 4 и 5",
            dots = BrailleDots(E, F, F, F, F, E)
        )
        +ShowDots(
            text = "Перед Вами полное шеститочие: <br>" +
                    "точки 1, 2, 3, 4, 5, 6",
            dots = BrailleDots(F, F, F, F, F, F)
        )
        +InputDots(
            // repeat = 3
            text = "Введите все шесть точек",
            dots = BrailleDots(F, F, F, F, F, F)
        )
        +Info(
            """Откройте букварь на странице 12. 
                В верхней строке 14 раз повторён символ полного шеститочия."""
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Info(
            """Первый урок закончен. В следующем уроке мы изучим буквы А, Б, Ц, Д, Е."""
        )
    }

    lesson(
        name = "Русские буквы А, Б, Ц, Д, Е"
    ) {
        +Info(
            """
                    <b>Урок 2. Буквы А, Б, Ц, Д, Е.</b>
                    <br><br>
                    Некоторые символы Брайля обозначают как букву, так и цифру. Это буквы А, Б,
                    Ц и так далее. С добавлением цифрового знака, который мы изучим в следующем
                    уроке, из них получаются цифры 1, 2, 3 и так далее."""
        )
        +Info(
            """Буква А обозначается одной точкой, точкой номер один.
                    Ознакомьтесь с ней в следующем шаге."""
        )
        +Show(content.symbols.getValue('А'))
        +Info(
            """Откройте букварь на странице 13. Вверху слева рельефно-графическое
                    изображение буквы А. Рядом после полного шеститочия пять раз повторена 
                    буква А точечным шрифтом."""
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Input(content.symbols.getValue('А')/*, repeat = 5*/)
        +Show(content.symbols.getValue('Б'))
        +Info(
            """Снова изучим страницу 13 в букваре. Под строкой с буквой А - 
                    такая же с буквой Б."""
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Input(content.symbols.getValue('Б'))
        +Info(
            """
                    Буква Ц: точки 1 и 4
                    <br><br>
                    Ознакомьтесь с буквой Ц на странице 13 букваря. 
                    Строка с буквой Ц находится под строкой с буквой Б."""
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Show(content.symbols.getValue('Ц'))
        +Input(content.symbols.getValue('Ц')/*, repeat = 5*/)
        +Show(content.symbols.getValue('Д'))
        +Input(content.symbols.getValue('Д')/*, repeat = 5*/)
        +Info(
            """Последняя буква в этом уроке - буква Е. 
                    Она обозначается двумя точками: номер 1 и 5."""
        )
        +Show(content.symbols.getValue('Е'))
        +Input(content.symbols.getValue('Е')/*, repeat = 5*/)
        +Info(
            """Урок 2 закончен. В следующем занятии займёмся повторением букв А, Б, Ц, Д, Е
                 и выучим буквы Ф, Г. Рекомендуем в дополнение к уроку потренироваться 
                 вводить изученные буквы в разделе "Практика"."""
        )
    }
    lesson(
        name = "Буквы Ф, Г"
    ) {
        +Info(
            """
                    <b>Урок 3. Буквы Ф, Г.</b>
                    <br><br>
                    Перед прохождением нового материала повторим пройденное.
                    В следующих трёх шагах нужно ввести буквы Б, А, Ц (вместе это слово БАЦ)."""
        )
        inputChars("БАЦ")
        +Info(
            """
                    Теперь познакомимся с буквами Ф и Г.
                    <br>
                    Буква Ф обозначается точками 1, 2 и 4.
                    <br>
                    Буква Г - точки 1, 2, 4 и 5.
                    <br>
                    В следующих четырёх шагах нужно ознакомиться с буквами и ввести их."""
        )
        +Show(content.symbols.getValue('Ф'))
        +Input(content.symbols.getValue('Ф')/*, repeat = 5*/)
        +Show(content.symbols.getValue('Г'))
        +Input(content.symbols.getValue('Г')/*, repeat = 5*/)
        +Info(
            """
                    В следующих трёх шагах введите по буквам слово БЕГ."""
        )
        inputChars("БЕГ")
        +Info(
            """Поздравляем! Третий урок пройден. В следующем занятии мы узнаем, 
                    как с помощью букв А, Б, Ц, Д, Е, Ф, Г составить цифры 1, 2, 3, 4, 5 и 6."""
        )
    }

    lesson(
        name = "Цифры от 1 до 6"
    ) {
        +Info(
            """
                    <b>Урок 4. Цифры от 1 до 6.</b>
                    <br><br>
                    В этом уроке мы начнём изучать цифры. Но для начала повторим пройденное.
                    В следующих шагах введите буквы, изученные в прошлых двух уроках."""
        )
        inputChars("АБЦДЕФГ")
        +Info(
            """
                    Переходим к изучению цифр.
                    <br>
                    Чтобы отличить цифры от букв, перед числами и цифрами ставится цифровой знак.
                    Этот символ обозначается точками 3, 4, 5, 6.
                    Когда нужно обозначить цифровой знак в обычном, плоскопечатном письме, 
                    как правило, пользуются символом правой квадратной скобки: ]"""
        )
        +Show(content.symbols.getValue(']'))
        +Input(content.symbols.getValue(']')/*, repeat = 3*/)
        +Info(
            """
                    В следующих шагах изучим цифры 1, 2, 3, 4, 5, 6, 7.
                    Они получаются из букв А, Б, Ц, Д, Е, Ф, Г добавлением цифрового знака.
                    Например, цифра и число 3 - это цифровой знак + Ц.
                    Число двадцать семь - это цифровой знак, затем буквы Б и Г. 
                    В уроках мы для краткости не будем всякий раз ставить цифровой знак."""
        )
        +Show(content.symbols.getValue('1'))
        +Input(content.symbols.getValue('1'))
        +Show(content.symbols.getValue('2'))
        +Input(content.symbols.getValue('2'))
        +Show(content.symbols.getValue('3'))
        +Input(content.symbols.getValue('3'))
        +Show(content.symbols.getValue('4'))
        +Input(content.symbols.getValue('4'))
        +Show(content.symbols.getValue('5'))
        +Input(content.symbols.getValue('5'))
        +Show(content.symbols.getValue('6'))
        +Input(content.symbols.getValue('6'))
        +Show(content.symbols.getValue('7'))
        +Input(content.symbols.getValue('7'))
        +Info(
            """
                    Урок 4 пройден! Рекомендуем самостоятельно изучить цифры и числа на странице 15
                    в букваре (внизу страницы).
                    <br>
                    Следующий урок будет посвящён повторению, а также мы изучим 
                    букву Х и цифру 8."""
        )
    }
}

/*
* In lessons with words input I tried to bear a scheme '6+-2 words'
* but there are several exceptions, e. g. where words are especially long/short
* or when new symbols are difficult
* */

internal val someMoreGolubinaLessons by lessons {

    lesson(
        name = "Буква Х и цифра 8"
    ) {
        +Info(
            """
                    <b>Урок 5. Буква Х и цифра 8.</b>
                    <br><br>
                    По окончании этого урока Вы узнаете букву Х и цифру 8. 
                    Но перед изучением нового повторим пройденное. Введите по буквам слово ФЕБ. """
        )
        inputChars("ФЕБ")
        +Info(
            """
                    В следующих шести шагах введите по буквам слово БАГДАД."""
        )
        inputChars("БАГДАД")
        inputChars("]123")
        +Info(
            """
                    Буква Х  обозначается точками 1, 2 и 5.
                    <br>
                    Цифра 8 - это цифровой знак и буква Х.
                    Потренируемся писать этот символ."""
        )
        +Show(content.symbols.getValue('Х'))
        +Input(content.symbols.getValue('Х'))
        +Input(content.symbols.getValue('8'))
        +Info(
            """
                    В следующих шагах введите различные символы, в том числе буквы Х и цифру 8.
                    """
        )
        inputChars("ЦЕХ")
        +Input(content.symbols.getValue(']'))
        +Input(content.symbols.getValue('8') /*, repeat = 5*/)
        +Input(content.symbols.getValue('7'))
        +Input(content.symbols.getValue('6'))
        inputChars("БАЦ")
        +Info(
            """
                    Урок 5 пройден! Материал о букве Х и цифре 8 находится на странице 16 в букваре.
                    Если у Вас есть возможность, изучите эту страницу самостоятельно.
                    <br>
                    На следующем занятии мы освоим буквы И и Ж, а также цифры 9 и 0"""
        )
    }

    lesson(
        name = "Буквы Ж, И и цифры 9, 0"
    ) {
        +Info(
            """
                    <b>Урок 6. Буквы Ж, И и цифры 9, 0</b>
                    <br><br>
                    Буква И - это точки 2 и 4.
                    Этот же символ с добавлением цифрового знака обозначает цифру 9.
                    <br>
                    Буква Ж - это точки 2, 4 и 5.
                    Цифровой знак и буква Ж образуют цифру 0.
                    <br>
                    Введите символы, которые образуют слово ЖАБА"""
        )
        inputChars("ЖАБА")
        +Info(
            """Введите буквы, составляющие слово БАГАЖ"""
        )
        inputChars("БАГАЖ")
        +Info(
            """Введите буквы, составляющие слово ЖАЖДА"""
        )
        inputChars("ЖАЖДА")
        +Info(
            """Напомним, буква И кодируется двумя точками с номерами 2 и 4.
                    Введите буквы, образующие слово ГИД"""
        )
        inputChars("ГИД")
        +Info(
            """Введите буквы, которые образуют слово ИЖИЦА"""
        )
        inputChars("ИЖИЦА")
        +Info(
            """Введите по символам число 850"""
        )
        inputChars("]850")
        +Info(
            """
                    Урок 6 закончен. Теперь Вы, помимо букв, знаете все цифры.
                    Буквы И, Ж и примеры к ним можно найти в букваре на странице 17.
                    <br>
                    Следующий урок посвящён буквам К, Л и М."""
        )
    }

    lesson(
        name = "Буквы К, Л, М"
    ) {
        +Info(
            """
                    <b>Урок 7. Буквы К, Л, М</b>
                    <br><br>
                    До сих пор мы изучали только буквы, образованные верхними четырьмя точками,
                    то есть точками 1, 2, 4, 5. В нескольких следующих уроках будут рассмотрены
                    буквы, содержащие, помимо того, точку три.
                    <br>
                    Перед занятием повторим пройденное. Введите по буквам слово ЕЖИХА.
                    """
        )
        inputChars("ЕЖИХА")
        +Info(
            """
                    Теперь перейдём к изучению материала.
                    <br>
                    Буква К: точки 1 и 3. Заметьте, она получается добавлением точки 3 к букве А.
                    <br>
                    Буква Л: точки 1, 2, 3. Как буква Б, но ещё с точкой 3.
                    <br>
                    Ознакомьтесь с этими буквами в следующих двух шагах.
                    """
        )
        +Show(content.symbols.getValue('К'))
        +Show(content.symbols.getValue('Л'))
        +Info(
            """Введите по буквам слово КЛАД"""
        )
        inputChars("КЛАД")
        +Info(
            """Введите по буквам слово БЕЛКА"""
        )
        inputChars("БЕЛКА")
        +Info(
            """
                    Сегодня осталось изучить букву М.
                    <br>
                    Буква М обозначается точками 1, 3 и 4. Она получается из буквы Ц 
                    при добавлении точки 3.
                    <br>
                    В следующем шаге буква М выведена на экран.
                    """
        )
        +Show(content.symbols.getValue('М'))
        +Info(
            """В следующих трёх шагах ведите по буквам слово МЕЛ"""
        )
        inputChars("МЕЛ")
        +Info(
            """Введите по буквам слово МАК"""
        )
        inputChars("МАК")
        +Info(
            """Напоследок введите по буквам слово ФИАЛКА"""
        )
        inputChars("ФИАЛКА")
        +Info(
            """
                    Мы подошли к концу урока 7.
                    Буквам К, Л, М посвящены страницы 19 и 20 букваря.
                    <br>
                    На следующем занятии мы узнаем, как обозначается буква Н."""
        )
    }

    lesson(
        name = "Буква Н"
    ) {
        +Info(
            """
                    <b>Урок 8. Буква Н.</b>
                    <br><br>
                    Рекомендуем в дополнение к этому уроку изучить букву Н 
                    на страницах 21 и 22 букваря.
                    <br>
                    Начнём занятие с повторения. Введите по буквам слово КАМБАЛА.
                    """
        )
        inputChars("КАМБАЛА")
        +Info(
            """
                    Отлично, теперь познакомимся с буквой Н.
                    <br>
                    Буква Н обозначается четырьмя точками: 1, 3, 4 и 5. 
                    Она образована точками буквы Д с добавлением точки номер 3.
                    <br>
                    В следующем шаге ознакомьтесь с этой буквой.
                    """
        )
        +Show(content.symbols.getValue('Н'))
        +Input(content.symbols.getValue('Н'))
        +Info(
            """Введите по буквам слово БАНАН"""
        )
        inputChars("БАНАН")
        +Info(
            """Введите по буквам слово ЦЕНА"""
        )
        inputChars("ЦЕНА")
        +Info(
            """Теперь введите по буквам слово БЛАНК"""
        )
        inputChars("БЛАНК")
        +Info(
            """
                    На этом урок 8 завершается.
                    <br>
                    В следующий раз изучим букву О и знак препинания ЗАПЯТАЯ.
                    """
        )
    }
    lesson(
        name = "Буква О и знак препинания 'Запятая'"
    ) {
        +Info(
            """
                    <b>Урок 9. Буква О и знак препинания "Запятая".</b>
                    <br><br>
                    Материалы к этому уроку есть на страницах 23-24 в букваре.
                    <br>
                    Как обычно, в начале занятия повторим пройденное.
                    Введите по буквам слово НАДЕЖДА.
                    """
        )
        inputChars("НАДЕЖДА")
        +Info(
            """
                    Идём дальше: теперь изучим букву 'О'.
                    <br>
                    Буква 'О' - это точки 1, 3 и 5. Если помните, точками 1 и 5 
                    обозначается буква Е, а О образуется из Е добавлением точки 3.
                    """
        )
        +Show(content.symbols.getValue('О'))
        +Info(
            """Наберите по буквам слово ОБЛАКО"""
        )
        inputChars("ОБЛАКО")
        +Info(
            """
                    Кратко ознакомимся со знаком 'Запятая'.
                    <br>
                    Запятая, как и буква А - только одна точка. Но если А - это точка 1, то запятая
                    - точка 2.
                    """
        )
        +Show(content.symbols.getValue(','))
        +Info(
            """Наберите по символам слово ЛОДКА и поставьте в конце запятую"""
        )
        inputChars("ЛОДКА,")
        +Info(
            """Аналогично предыдущему, введите слово КОФЕ и запятую"""
        )
        inputChars("КОФЕ,")
        +Info(
            """Напоследок введите слово ГЕОЛОГ и тоже поставьте запятую в конце"""
        )
        inputChars("ГЕОЛОГ,")
        +Info(
            """Урок 9 подходит к концу. В следующем уроке нас ждёт изучение буквы П."""
        )
    }
    lesson(
        name = "Буква П"
    ) {
        +Info(
            """
                    <b>Урок 10. Буква П.</b>
                    <br><br>
                    Этот урок полезно закрепить, изучив страницу 25 в книге Голубиной.
                    <br>
                    В виде разминки перед уроком повторим изученные ранее символы.
                    Введите по буквам слово МОЛОКО и поставьте после него запятую.
                    """
        )
        inputChars("МОЛОКО,")
        +Info(
            """
                    Давайте познакомимся с буквой 'П'.
                    <br>
                    Буква 'П' представлена точками 1, 2, 3 и 4. Напомним, точки 1, 2 и 4 образуют
                    букву Ф. Букву П можно получить из Ф, добавив точку номер 3.
                    """
        )
        +Show(content.symbols.getValue('П'))
        +Info(
            """Введите отдельными символами слово ПЕНА"""
        )
        inputChars("ПЕНА")
        +Info(
            """Теперь нужно набрать по буквам слово ЛАМПА"""
        )
        inputChars("ЛАМПА")
        +Info(
            """Наберите по буквам слово ПЛАН"""
        )
        inputChars("ПЛАН")
        +Info(
            """И последнее в этом уроке: введите по буквам слово КАПКАН"""
        )
        inputChars("КАПКАН")
        +Info(
            """Вот и пройден десятый урок. Следующее занятие отведено для изучения буквы Ч"""
        )
    }

    lesson(
        name = "Буква Ч"
    ) {
        +Info(
            """
                    <b>Урок 11. Буква Ч.</b>
                    <br><br>
                    Буква Ч и слова с ней находятся на странице 26 в букваре Голубиной.
                    <br>
                    Перед началом работы немного повторим прошлые уроки.
                    Введите по буквам слово ХЛОПОК.
                    """
        )
        inputChars("ХЛОПОК")
        +Info(
            """Введите отдельными символами число 215, поставив перед ним цифровой знак"""
        )
        inputChars("]215")

        +Info(
            """
                    Переходим к изучению новой буквы: 'Ч'.
                    <br>
                    Русская буква 'Ч' в азбуке Брайля составлена из точек 1, 2, 3, 4 и 5. 
                    Её можно получить из буквы Г, если дополнить точкой 3.
                    """
        )
        +Show(content.symbols.getValue('Ч'))
        +Info(
            """Введите по буквам слово ЧЕК"""
        )
        inputChars("ЧЕК")
        +Info(
            """Наберите отдельными буквами слово ОЧКИ"""
        )
        inputChars("ОЧКИ")
        +Info(
            """Далее введите по буквам слово КОЧАН"""
        )
        inputChars("КОЧАН")
        +Info(
            """Введите по буквам ещё одно, последнее слово: БОЧОНОК"""
        )
        inputChars("БОЧОНОК")
        +Info(
            """
                    Урок 11, в котором мы изучали букву 'Ч', позади. 
                    А в следующий раз мы будем заниматься буквой Р.
                    """
        )
    }
    lesson(
        name = "Буква Р"
    ) {
        +Info(
            """
                    <b>Урок 12. Буква Р.</b>
                    <br><br>
                    Этому уроку соответствует страницы 27 и 28 букваря.
                    <br>
                    Перед стартом повторим материал прошлых уроков. 
                    Введите по символам слово ПЧЕЛА.
                    """
        )
        inputChars("ПЧЕЛА")
        +Info(
            """
                    Сегодня мы изучим букву 'Р'.
                    <br>
                    Буква 'Р' формируется из точек с номерами 1, 2, 3 и 5. 
                    Иначе говоря, буква Р - это буква Х и точка 3.
                    """
        )
        +Show(content.symbols.getValue('Р'))
        +Info(
            """Наберите последовательно, по буквам слово РЕКА"""
        )
        inputChars("РЕКА")
        +Info(
            """Наберите отдельными символами слово КРАН"""
        )
        inputChars("КРАН")
        +Info(
            """Далее в четырёх шагах введите по буквам слово КРЕМ"""
        )
        inputChars("КРЕМ")
        +Info(
            """Теперь введите по символам слово ФАРА"""
        )
        inputChars("ФАРА")
        +Info(
            """Наберите аналогичным образом последнее слово в сегодняшнем уроке: ГАРАЖ"""
        )
        inputChars("ГАРАЖ")
        +Info(
            """
                    Урок 12 завершён. Теперь мы, помимо прочего, знаем точечный состав буквы 'Р'.
                    За этим уроком следует занятие, посвящённое букве С.
                    """
        )
    }
    lesson(
        name = "Буква С"
    ) {
        +Info(
            """
                    <b>Урок 13. Буква С.</b>
                    <br><br>
                    Буква С изучается в букваре на странице 29.
                    <br>
                    Перед уроком вспомним старый материал.
                    Введите по буквам слово МАРАФОН
                    """
        )
        inputChars("МАРАФОН")
        +Info(
            """
                    Предмет этого урока - буква 'С'.
                    <br>
                    Буква 'С' в азбуке Брайля представлена точками 2, 3 и 4.
                    Точками 2 и 4, как вы помните, обозначается буква И. Буква С - это буква И,
                    дополненная точкой номер 3.
                    """
        )
        +Show(content.symbols.getValue('С'))
        +Info(
            """В следующих шагах наберите слово САЖА"""
        )
        inputChars("САЖА")
        +Info(
            """Наберите по буквам слово СЛЕД"""
        )
        inputChars("СЛЕД")
        +Info(
            """Введите буквы, образующие слово ФАСАД"""
        )
        inputChars("ФАСАД")
        +Info(
            """Введите буквы, которые составляют слово ДОСКА"""
        )
        inputChars("ДОСКА")
        +Info(
            """В завершение урока введите по буквам слово ЧЕСНОК"""
        )
        inputChars("ЧЕСНОК")
        +Info(
            """
                    Урок 13 завершён. Теперь мы, помимо прочего, знаем точечный состав буквы 'Р'.
                    За этим уроком следует занятие, посвящённое букве С.
                    Мы подошли к финалу урока 13. К этому моменту мы уже изучили 19 букв,
                    знак препинания 'ЗАПЯТАЯ' и цифры. В следующем уроке изучим букву Т.
                    """
        )
    }
    lesson(
        name = "Буква Т и знак 'Дефис'"
    ) {
        +Info(
            """
                    <b>Урок 14. Буква Т и знак 'Дефис'.</b>
                    <br><br>
                    В букваре В. В. Голубиной Вы найдёте урок о букве Т на странице 30 
                    и о знаке 'Дефис' на странице 31.
                    <br>
                    Как обычно, предварим урок повторением пройденного.
                    Введите символы, составляющие слово СОЛНЦЕ
                    """
        )
        inputChars("СОЛНЦЕ")
        +Info(
            """Теперь наберите число 870, сначала поставив цифровой знак"""
        )
        inputChars("]870")
        +Info(
            """
                    Теперь рассмотрим букву 'Т'.
                    <br>
                    Буква 'Т' в алфавите Брайля - это точки 2, 3, 4 и 5.
                    Поскольку точками 2, 4 и 5 образована буква Х, то буква Т - это буква Х 
                    и ещё точка номер 3.
                    """
        )
        +Show(content.symbols.getValue('Т'))
        +Info(
            """Далее, пожалуйста, введите слово ТЕКСТ"""
        )
        inputChars("ТЕКСТ")
        +Info(
            """Введите по буквам слово ТОРТ"""
        )
        inputChars("ТОРТ")
        +Info(
            """
                    С этого момента мы начинаем осваивать символы, содержащие точку 6.
                    Прямо сейчас перейдём к изучению дефиса.
                    <br>
                    Знак 'Дефис' обозначается точками 3 и 6. Не нужно путать его с буквой Ц: 
                    точки буквы Ц - в верхней трети шеститочия, точки дефиса - в самой нижней.
                    """
        )
        +Show(content.symbols.getValue('-'))
        +Info(
            """Введите по символам слово ПОЛ-ЛИМОНА"""
        )
        inputChars("ПОЛ-ЛИМОНА")
        +Info(
            """И последнее слово, которое нужно ввести в этом уроке - местоимение ГДЕ-ЛИБО"""
        )
        inputChars("ГДЕ-ЛИБО")
        +Info(
            """
                    На этом урок 14 закончен. Буква Т, которой он был посвящён, стала двадцатой
                    изученной нами. Также мы познакомились со знаком 'дефис'.
                    В следующий раз перейдём к букве У.
                    """
        )
    }
    lesson(
        name = "Буква У"
    ) {
        +Info(
            """
                    <b>Урок 15. Буква У.</b>
                    <br><br>
                    В книге Голубиной буква У вводится на странице 32.
                    <br>
                    Вспомним для начала материал прошлых уроков.
                    На следующих этапах введите по буквам слово ТЕЛЕФОН
                    """
        )
        inputChars("ТЕЛЕФОН")
        +Info(
            """
                    Начинаем знакомство с буквой У. Эта буква первая в нашем курсе содержит точку 6.
                    <br>
                    Буква 'У' обозначается точками номер 1, 3 и 6.
                    """
        )
        +Show(content.symbols.getValue('У'))
        +Info(
            """В следующих шагах введите, пожалуйста, слово УГОЛ"""
        )
        inputChars("УГОЛ")
        +Info(
            """Наберите, последовательно вводя буквы, слово ЛУНА"""
        )
        inputChars("ЛУНА")
        +Info(
            """Введите буквы, формирующие слово КРУГ"""
        )
        inputChars("КРУГ")
        +Info(
            """Введите буквы, которые бы составили слово ТРУД"""
        )
        inputChars("ТРУД")
        +Info(
            """Последнее, что нужно сделать в этом уроке - введите слово ЧУДЕСА"""
        )
        inputChars("ЧУДЕСА")
        +Info(
            """
                    Урок 15 окончен. Мы изучили букву У - первую букву, где нам встретилась точка
                    номер 6 (но не первый символ: ранее мы сталкивались с ним, изучая цифровой знак
                    и знак 'Дефис'). В следующем занятии нас ждёт буква Щ.
                    """
        )
    }
    lesson(
        name = "Буква Щ"
    ) {
        +Info(
            """
                    <b>Урок 16. Буква Щ.</b>
                    <br><br>
                    Букварь содержит урок с буквой Щ на странице 33.
                    <br>
                    В виде разминки повторим ранее изученное.
                    Введите буквы, которые сложатся в слово ХУДОЖНИК
                    """
        )
        inputChars("ХУДОЖНИК")
        +Info(
            """
                    Ознакомимся с буквой Щ.
                    <br>
                    Буква 'Щ' состоит из четырёх точек с номерами 1, 3, 4 и 6. Как буква Ц
                    и знак дефиса в одной клеточке.
                    """
        )
        +Show(content.symbols.getValue('Щ'))
        +Info(
            """Вводя букву за буквой, составьте слово ЩЕГОЛ"""
        )
        inputChars("ЩЕГОЛ")
        +Info(
            """Теперь наберите, пожалуйста, слово ПЛАЩ"""
        )
        inputChars("ПЛАЩ")
        +Info(
            """Наберите отдельными буквами слово КЛЕЩ"""
        )
        inputChars("КЛЕЩ")
        +Info(
            """Наберите буквы, которые бы составили слово ЩЕПКА"""
        )
        inputChars("ЩЕПКА")
        +Info(
            """Перед тем, как мы закончим занятие, введите слово ОЩУЩЕНИЕ"""
        )
        inputChars("ОЩУЩЕНИЕ")
        +Info(
            """
                    Урок 16 - буква Щ - подходит к завершению. Теперь нам известны 22 буквы русского
                    алфавита. Следующее занятие будет на тему буквы З.
                    """
        )
    }
    lesson(
        name = "Буква З"
    ) {
        +Info(
            """
                    <b>Урок 17. Буква З.</b>
                    <br><br>
                    В книге Голубиной букву З можно найти на странице 34.
                    <br>
                    Новый материал мы будем изучать после краткого повторения.
                    Далее введите буквы слова ЩЕПОТКА
                    """
        )
        inputChars("ЩЕПОТКА")
        +Info(
            """
                    Новая буква, которую нам надо изучить - З.
                    <br>
                    Буква 'З' образована точками 1, 3, 5 и 6. Её можно составить, соединив в одной
                    клетке букву Е и знак 'дефис'.
                    """
        )
        +Show(content.symbols.getValue('З'))
        +Info(
            """Последовательно, по буквам введите слово ЗАКАЗ"""
        )
        inputChars("ЗАКАЗ")
        +Info(
            """Теперь из отдельных букв наберите слово ЗЕРНО"""
        )
        inputChars("ЗЕРНО")
        +Info(
            """Наберите по буквам очень важное для нас слово АЗБУКА"""
        )
        inputChars("КЛЕЩ")
        +Info(
            """В следующих пяти шагах введите слово АРБУЗ"""
        )
        inputChars("АРБУЗ")
        +Info(
            """И последнее, что сегодня осталось сделать: введите слово ЗАДАЧА"""
        )
        inputChars("ЗАДАЧА")
        +Info(
            """                    
                    Вы успешно окончили урок 17 - буква З. На следующем занятии перейдём к освоению
                    буквы И краткое.
                    """
        )
    }
    lesson(
        name = "Буква Й"
    ) {
        +Info(
            """
                    <b>Урок 18. Буква "И краткое".</b>
                    <br><br>
                    Букварь Голубиной содержит материал на тему буквы Й на странице 35.
                    <br>
                    Знакомство с новой буквой начнём после небольшой ревизии ранее пройденного.
                    Пожалуйста, введите буквы, образующие слово МИМОЗА
                    """
        )
        inputChars("МИМОЗА")
        +Info(
            """Также в качестве повторения введите цифровой знак, а за ним число 964"""
        )
        inputChars("]964")
        +Info(
            """
                    Переходим к главному в сегодняшнем уроке: ознакомимся с буквой 'И краткое'.
                    <br>
                    Буква 'Й' обозначается пятью точками с номерами 1, 2, 3, 4 и 6, 
                    до полного шеститочия не хватает лишь точки 5. Букву 'Й' можно получить из буквы
                    П, добавив точку номер 6.
                    """
        )
        +Show(content.symbols.getValue('Й'))
        +Info(
            """Буква за буквой, введите точечным шрифтом слово КЛЕЙ"""
        )
        inputChars("КЛЕЙ")
        +Info(
            """Введите отдельными символами второе слово с буквой Й: УЛЕЙ"""
        )
        inputChars("УЛЕЙ")
        +Info(
            """Наберите, пожалуйста, по буквам слово РЕЙС"""
        )
        inputChars("РЕЙС")
        +Info(
            """Осталось ещё два задания. В следующих четырёх шагах введите слово ЗНОЙ"""
        )
        inputChars("ЗНОЙ")
        +Info(
            """Наконец, введите последнее слово в этом уроке: РАЙОН"""
        )
        inputChars("РАЙОН")
        +Info(
            """                    
                    Урок 18 - буква 'И краткое' - окончен. Теперь мы знаем уже 4 буквы, содержащие
                    точку номер 6. Предлагаем Вам самостоятельно вспомнить, какие именно.
                    <br>
                    До встречи на следующем уроке, где мы будем изучать твёрдый знак и 
                    знак препинания 'Литературная точка'.
                    """
        )
    }
    lesson(
        name = "Твёрдый знак и литературная точка"
    ) {
        +Info(
            """
                    <b>Урок 19. Твёрдый знак и литературная точка.</b>
                    <br><br>
                    Желательно во время или после занятия прочесть соответствующий раздел букваря
                    на странице 36.
                    <br>
                    Вначале повторим ранее изученные буквы.
                    Введите по буквам прилагательное ОСЕННИЙ
                    """
        )
        inputChars("ОСЕННИЙ")
        +Info(
            """
                    Мы готовы к изучению твёрдого знака.
                    <br>
                    Твёрдый знак - это точки 1, 2, 3, 5 и 6. Почти полное шеститочие, нет только
                    точки номер 4. Твёрдый знак получается из буквы 'Р' добавлением точки 6.
                    """
        )
        +Show(content.symbols.getValue('Ъ'))
        +Info(
            """Введите по буквам слово СЪЕЗД"""
        )
        inputChars("СЪЕЗД")
        +Info(
            """Символ за символом, наберите слово СУБЪЕКТ"""
        )
        inputChars("СУБЪЕКТ")
        +Info(
            """
                    Теперь постараемся запомнить обозначение литературной точки.
                    <br>
                    Знак препинания 'Литературная точка' образован в азбуке Брайля точками 2, 5 и 6.
                    Не следует путать его с буквой Д.
                    """
        )
        +Show(content.symbols.getValue('.'))
        +Input(content.symbols.getValue('.'))
        +Info(
            """
                    В следующих шагах введите по буквам целое предложение: "Ленинград - город-герой".
                    <br>
                    В конце поставьте литературную точку.
                    """
        )
        inputChars("ЛЕНИНГРАД-ГОРОД-ГЕРОЙ")
        +Info(
            """                    
                    На этом мы завершаем занятие номер 19. Осталось ещё семь уроков, после чего 
                    мы будем знать все русские буквы. В следующем уроке узнаем точечный состав
                    буквы Ы.
                    """
        )
    }
    lesson(
        name = "Буква Ы"
    ) {
        +Info(
            """
                    <b>Урок 20. Буква Ы.</b>
                    <br><br>
                    Если Вы хотите найти урок с буквой Ы в букваре, посетите страницы 37 и 38.
                    <br>
                    А сейчас ради закрепления пройденного введите по символам слово ОБЪЕДИНЕНИЕ
                    """
        )
        inputChars("ОБЪЕДИНЕНИЕ")
        +Info(
            """Также повторим специальные символы.
                    Введите цифровой знак, запятую, дефис и точку"""
        )
        inputChars("],-.")
        +Info(
            """
                    Переходим к изучению точечного состава буквы Ы.
                    <br>
                    Буква Ы представлена точками с номерами 2, 3, 4 и 6. Как несложно заметить,
                    букву Ы можно получить добавлением точки номер 6 к букве С.
                    """
        )
        +Show(content.symbols.getValue('Ы'))
        +Info(
            """Набирая буквы одна за одной, введите слово МЫЛО"""
        )
        inputChars("МЫЛО")
        +Info(
            """Далее введите ещё одно слово по буквам: ЛЫЖИ"""
        )
        inputChars("ЛЫЖИ")
        +Info(
            """Теперь введите буквы, из которых складывается слово КЛЫК"""
        )
        inputChars("КЛЫК")
        +Info(
            """Наберите предпоследнее слово в этом уроке - слово МУЗЫКА"""
        )
        inputChars("МУЗЫКА")
        +Info(
            """Введите последнее слово - существительное во множественном числе: КОЗЫ"""
        )
        inputChars("КОЗЫ")
        +Info(
            """                    
                    Урок 20 - буква 'Ы' - подходит к завершению.
                    Остались неизученными семь букв русского алфавита; для них отведены оставшиеся
                    шесть уроков. На следующем занятии будем осваивать мягкий знак.
                    """
        )
    }
    lesson(
        name = "Мягкий знак"
    ) {
        +Info(
            """
                    <b>Урок 21. Мягкий знак.</b>
                    <br><br>
                    В дополнение к этому уроку можно изучить страницы 39 и 40 в букваре.
                    <br>
                    Как и в прошлые разы, перед занятием повторим ранее изученное.
                    Введите, набирая отдельные буквы, прилагательное РЫЖИЙ
                    """
        )
        inputChars("РЫЖИЙ")
        +Info(
            """
                    Два урока назад мы изучали твёрдый знак, а теперь освоим и мягкий знак тоже.
                    <br>
                    Мягкий знак обозначается точками 2, 3, 4, 5 и 6. Он получается из буквы Т и
                    точки номер 6.
                    """
        )
        +Show(content.symbols.getValue('Ь'))
        +Info(
            """Введите по буквам существительное СОЛЬ"""
        )
        inputChars("СОЛЬ")
        +Info(
            """Теперь нужно ввести слово МЕЛЬ"""
        )
        inputChars("МЕЛЬ")
        +Info(
            """Далее, пожалуйста, составьте из букв слово КОНЬ"""
        )
        inputChars("КОНЬ")
        +Info(
            """Осталось ввести два слова.
                    Первое - существительное во множественном числе: РУЧЬИ"""
        )
        inputChars("РУЧЬИ")
        +Info(
            """Введите последнее в этом занятии слово: СТАЛЬ"""
        )
        inputChars("СТАЛЬ")
        +Info(
            """                    
                    Урок 21, в котором мы изучили мягкий знак, пройден.
                    В течение следующего занятия мы изучим сразу две буквы: Ё и Ш.
                    """
        )
    }
    lesson(
        name = "Буквы Ё и Ш"
    ) {
        +Info(
            """
                    <b>Урок 22. Буквы Ё и Ш.</b>
                    <br><br>
                    Вводный текст о буквах Ё и Ш можно найти в букваре на страницах 41 и 42.
                    <br>
                    Перед уроком будет полезно вспомнить буквы, пройденные на прошлых занятиях.
                    Введите шаг за шагом слово АПЕЛЬСИН
                    """
        )
        inputChars("АПЕЛЬСИН")
        +Info(
            """
                    Теперь приступим к изучению буквы, которая сравнительно недавно появилась 
                    в русском языке - буквы Ё.
                    <br>
                    Буква 'Ё' обозначается двумя точками с номерами 1 и 6. Она получается из буквы А
                    добавлением точки 6.
                    """
        )
        +Show(content.symbols.getValue('Ё'))
        +Info(
            """Шаг за шагом введите слово ЁЛКА"""
        )
        inputChars("ЁЛКА")
        +Info(
            """Введите далее название имя ещё одного дерева - КЛЁН"""
        )
        inputChars("КЛЁН")
        +Info(
            """
                    Теперь давайте посмотрим на букву Ш.
                    <br>
                    Буква 'Ш' формируется из точек номер 1, 5 и 6. Её можно получить, приписав к 
                    букве Е точку 6.
                    """
        )
        +Show(content.symbols.getValue('Ш'))
        +Info(
            """Наберите отдельными символами слово ШЁЛК"""
        )
        inputChars("ШЁЛК")
        +Info(
            """Теперь введите буквы, которые вместе складываются в слово ШЕСТ"""
        )
        inputChars("ШЕСТ")
        +Info(
            """Введите предпоследнее слово в нашем уроке, слово ШАРФ"""
        )
        inputChars("ШАРФ")
        +Info(
            """Наконец, перед тем, как мы закончим урок, введите слово КОШКА"""
        )
        inputChars("КОШКА")
        +Info(
            """                    
                    Урок 22, посвящённый буквам Ё и Ш, завершён.
                    <br>
                    До окончания изучения всего алфавита осталось 4 урока и 4 буквы: В, Э, Ю, Я.
                    В следующем уроке введём букву Я.
                    """
        )
    }
    lesson(
        name = "Буква Я"
    ) {
        +Info(
            """
                    <b>Урок 23. Буква 'Я'.</b>
                    <br><br>
                    Изучению буквы 'Я' отведены страницы 43 и 44 в букваре Голубиной.
                    <br>
                    Мы выучили уже много букв, и перед занятием повторим часть из них.
                    Введите по буквам слово МИШЕНЬ
                    """
        )
        inputChars("МИШЕНЬ")
        +Info(
            """
                    Познакомимся с точечным составом буквы, последней в зрячем алфавите, 
                    но не в нашем курсе - с буквой Я.
                    <br>
                    Буква 'Я' - это точки 1, 2, 4 и 6. Иначе говоря, эта буква составлена из точек
                    буквы 'Ф' и точки 6 в одной клетке.
                    """
        )
        +Show(content.symbols.getValue('Я'))
        +Info(
            """Введите брайлевские буквы, которые составляют слово ЯБЛОКО"""
        )
        inputChars("ЯБЛОКО")
        +Info(
            """В следующих пяти шагах нужно ввести слово ЯГОДА"""
        )
        inputChars("ЯГОДА")
        +Info(
            """Далее, пожалуйста, наберите отдельными буквами слово ПЯТНО"""
        )
        inputChars("ПЯТНО")
        +Info(
            """Ещё два слова нужно ввести в этом уроке.
                    <br>
                    Первое - название птицы: ЦАПЛЯ"""
        )
        inputChars("ЦАПЛЯ")
        +Info(
            """Последнее слово в сегодняшнем уроке - ЗЕМЛЯ"""
        )
        inputChars("ЗЕМЛЯ")
        +Info(
            """
                    Урок 23 - буква Я - успешно завершён.
                    В следующий раз мы будем осваивать букву Ю.
                    """
        )
    }
    lesson(
        name = "Буква Ю"
    ) {
        +Info(
            """
                    <b>Урок 24. Буква 'Ю'.</b>
                    <br><br>
                    Буква 'Ю' и слова с ней находятся на страницах 45 и 46 в букваре. 
                    <br>
                    Начнём с ревизии уже изученных букв и специальных символов.
                    Введите, набирая отдельные буквы, слово ПОЛЯНА и поставьте после него запятую
                    """
        )
        inputChars("ПОЛЯНА,")
        +Info(
            """
                    В этом уроке нам надо познакомиться с буквой Ю.
                    <br>
                    Буква 'Ю' обозначается четырьмя точками: 2, 3, 5 и 6. Иначе, она составлена из
                    буквы Х и дополнительной точки 6.
                    """
        )
        +Show(content.symbols.getValue('Ю'))
        +Info(
            """Наберите по символам слово с новой буквой: ЮБКА"""
        )
        inputChars("ЮБКА")
        +Info(
            """В следующих четырёх шагах наберите слово УТЮГ"""
        )
        inputChars("УТЮГ")
        +Info(
            """Заметьте, что буква Т и буква Ю получаются друг из друга отражением 
                    по вертикали. 
                    <br>
                    После этого шага, пожалуйста, введите по буквам слово ТЮБИК"""
        )
        inputChars("ТЮБИК")
        +Info(
            """Нам осталось выполнить два задания, после чего урок заканчивается.
                    <br>
                    Первое: введите слово ТРЮК"""
        )
        inputChars("ТРЮК")
        +Info(
            """Завершающее задание в этом уроке - введите буквы слова СЮЖЕТ"""
        )
        inputChars("СЮЖЕТ")
        +Info(
            """
                    Урок 24 - русская буква Ю - закончен. Нам осталось пройти всего два занятия,
                    после чего весь алфавит будет изучен.
                    <br>
                    В нашей предпоследней встрече мы освоим букву Э.
                    """
        )
    }
    lesson(
        name = "Буква Э"
    ) {
        +Info(
            """
                    <b>Урок 25. Буква 'Э'.</b>
                    <br><br>
                    Для развития памяти пальцев рекомендуется в дополнение к этому уроку
                    просмотреть материал о букве Э на страницах 47 и 48 в букваре. 
                    <br>
                    Перед погружением в новый материал повторим пройденное.
                    Введите по буквам слово ИНТЕРЕСНЫЙ
                    """
        )
        inputChars("ИНТЕРЕСНЫЙ")
        +Info(
            """Ещё перед началом урока мы чуть-чуть повторим числа. Введите цифровой знак и
                    за ним число 1984
                    """
        )
        inputChars("]1984")
        +Info(
            """
                    Давайте изучим букву 'Э'.
                    <br>
                    Буква 'Э' представлена комбинацией трёх точек: 2, 4 и 5. Она составлена из буквы
                    'И' плюс точка 6.
                    """
        )
        +Show(content.symbols.getValue('Э'))
        +Info(
            """Вводя отдельные буквы, составьте слово ЭХО"""
        )
        inputChars("ЭХО")
        +Info(
            """Обратите внимание, буква 'Э' образуется зеркальным отражением буквы 'О'
                    вдоль вертикальной оси.
                    <br>
                    В следующих пяти шагах наберите по буквам слово ПОЭМА"""
        )
        inputChars("ПОЭМА")
        +Info(
            """Теперь мы попросим Вас ввести слово ЭКРАН"""
        )
        inputChars("ЭКРАН")
        +Info(
            """
                    В этом уроке ещё два задания на ввод слов.
                    <br>
                    Первое из них: составьте слово ЭПИЗОД"""
        )
        inputChars("ЭПИЗОД")
        +Info(
            """В последнем задании нужно ввести слово ЭСТРАДА"""
        )
        inputChars("ЭСТРАДА")
        +Info(
            """
                    Урок 25, в ходе которого мы выучили букву Э, закончен.
                    <br>
                    В следующем уроке, который станет последним в нашем курсе, изучим букву В.
                    """
        )
    }
    lesson(
        name = "Буква В"
    ) {
        +Info(
            """
                    <b>Урок 26. Буква 'В'.</b>
                    <br><br>
                    Для более тщательного изучения буквы 'В' мы рекомендуем обратиться к букварю
                    Голубиной, страницы 49 и 50.
                    <br>
                    В начале этого занятия вспомним материал, ранее пройденный в курсе.
                    Пожалуйста, наберите буквы, составляющие слово ЭНЦИКЛОПЕДИЯ
                    """
        )
        inputChars("ЭНЦИКЛОПЕДИЯ")
        +Info(
            """
                    Изучим последнюю букву, которую мы пока не рассматривали - букву 'В'.
                    <br>
                    Буква 'В' в азбуке Брайля - это комбинация четырёх точек: 2, 4, 5 и 6. Её можно
                    составить, написав букву 'Ж' и добавив точку номер 6 в той же клетке. 
                    """
        )
        +Show(content.symbols.getValue('В'))
        +Info(
            """Наберите первое слово с буквой 'В' - слово ВОР"""
        )
        inputChars("ВОР")
        +Info(
            """Мы не случайно привели слово, содержащее буквы 'В' и 'Р'. Обратите внимание, что
                    каждая из них получается зеркальным отражением другой по вертикали.
                    <br>
                    Далее введите по символам слово ВРАЧ"""
        )
        inputChars("ВРАЧ")
        +Info(
            """В следующих шести шагах введите, пожалуйста, буквы слова ВОРОНА"""
        )
        inputChars("ВОРОНА")
        +Info(
            """
                    Нужно составить ещё два слова.
                    <br>
                    Введите по буквам слово СЕВЕР"""
        )
        inputChars("СЕВЕР")
        +Info(
            """Заключительное упражнение: наберите слово КОРОВА"""
        )
        inputChars("КОРОВА")
        +LastInfo(
            """
                    Урок 26 - буква В - закончен.
                    <br>
                    Вы дошли до конца курса. Спасибо, что воспользовались нашим обучающим
                    приложением! При желании можно вернутся к ранее пройденному материалу 
                    и повторить его.
                    <br><br>
                    Помните, что для успешного закрепления навыков чтения по Брайлю нужна практика.
                    Мы советуем Вам читать различные книги рельефно-точечным шрифтом. Желаем вам
                    приятного опыта использования алфавита Луи Брайля!
                    """
        )
    }
}
